==> bonita-server-6.5.2.jar: sql/oracle/dropTables.sql <==
DROP TABLE actormember cascade constraints purge;
DROP TABLE actor cascade constraints purge;
DROP TABLE processcategorymapping cascade constraints purge;
DROP TABLE category cascade constraints purge;
DROP TABLE migration_plan cascade constraints purge;
DROP TABLE arch_process_comment cascade constraints purge;
DROP TABLE process_comment cascade constraints purge;
DROP TABLE process_definition cascade constraints purge;
DROP TABLE arch_document_mapping cascade constraints purge;
DROP TABLE document_mapping cascade constraints purge;
DROP TABLE document cascade constraints purge;
DROP TABLE arch_flownode_instance cascade constraints purge;
DROP TABLE arch_process_instance cascade constraints purge;
DROP TABLE arch_transition_instance cascade constraints purge;
DROP TABLE arch_connector_instance cascade constraints purge;
DROP TABLE multi_biz_data cascade constraints purge;
DROP TABLE ref_biz_data_inst cascade constraints purge;
DROP TABLE pending_mapping cascade constraints purge;
DROP TABLE connector_instance cascade constraints purge;
DROP TABLE flownode_instance cascade constraints purge;
DROP TABLE process_instance cascade constraints purge;
DROP TABLE event_trigger_instance cascade constraints purge;
DROP TABLE waiting_event cascade constraints purge;
DROP TABLE message_instance cascade constraints purge;
DROP TABLE breakpoint cascade constraints purge;
DROP TABLE report cascade constraints purge;
DROP TABLE processsupervisor cascade constraints purge;
DROP TABLE business_app_menu cascade constraints purge;
DROP TABLE business_app_page cascade constraints purge;
DROP TABLE business_app cascade constraints purge;
DROP TABLE command cascade constraints purge;
DROP TABLE arch_data_instance cascade constraints purge;
DROP TABLE data_instance cascade constraints purge;
DROP TABLE dependencymapping cascade constraints purge;
DROP TABLE dependency cascade constraints purge;
DROP TABLE pdependencymapping cascade constraints purge;
DROP TABLE pdependency cascade constraints purge;
DROP TABLE external_identity_mapping cascade constraints purge;
DROP TABLE user_membership cascade constraints purge;
DROP TABLE custom_usr_inf_val cascade constraints purge;
DROP TABLE custom_usr_inf_def cascade constraints purge;
DROP TABLE user_contactinfo cascade constraints purge;
DROP TABLE user_login cascade constraints purge;
DROP TABLE user_ cascade constraints purge;
DROP TABLE role cascade constraints purge;
DROP TABLE group_ cascade constraints purge;
DROP TABLE queriablelog_p cascade constraints purge;
DROP TABLE queriable_log cascade constraints purge;
DROP TABLE page cascade constraints purge;
DROP TABLE theme cascade constraints purge;
DROP TABLE blob_ cascade constraints purge;
DROP TABLE profilemember cascade constraints purge;
DROP TABLE profileentry cascade constraints purge;
DROP TABLE profile cascade constraints purge;
DROP TABLE job_log cascade constraints purge;
DROP TABLE job_param cascade constraints purge;
DROP TABLE job_desc cascade constraints purge;
DROP TABLE sequence cascade constraints purge;
DROP TABLE tenant cascade constraints purge;
DROP TABLE platform cascade constraints purge;
DROP TABLE platformCommand cascade constraints purge;

==> bonita-server-7.0.1.jar: sql/oracle/dropTables.sql <==
DROP TABLE arch_contract_data cascade constraints purge;
DROP TABLE contract_data cascade constraints purge;
DROP TABLE actormember cascade constraints purge;
DROP TABLE actor cascade constraints purge;
DROP TABLE processcategorymapping cascade constraints purge;
DROP TABLE category cascade constraints purge;
DROP TABLE arch_process_comment cascade constraints purge;
DROP TABLE process_comment cascade constraints purge;
DROP TABLE process_definition cascade constraints purge;
DROP TABLE arch_document_mapping cascade constraints purge;
DROP TABLE document_mapping cascade constraints purge;
DROP TABLE document cascade constraints purge;
DROP TABLE arch_flownode_instance cascade constraints purge;
DROP TABLE arch_process_instance cascade constraints purge;
DROP TABLE arch_transition_instance cascade constraints purge;
DROP TABLE arch_connector_instance cascade constraints purge;
DROP TABLE multi_biz_data cascade constraints purge;
DROP TABLE ref_biz_data_inst cascade constraints purge;
DROP TABLE pending_mapping cascade constraints purge;
DROP TABLE connector_instance cascade constraints purge;
DROP TABLE flownode_instance cascade constraints purge;
DROP TABLE process_instance cascade constraints purge;
DROP TABLE event_trigger_instance cascade constraints purge;
DROP TABLE waiting_event cascade constraints purge;
DROP TABLE message_instance cascade constraints purge;
DROP TABLE report cascade constraints purge;
DROP TABLE processsupervisor cascade constraints purge;
DROP TABLE business_app_menu cascade constraints purge;
DROP TABLE business_app_page cascade constraints purge;
DROP TABLE business_app cascade constraints purge;
DROP TABLE command cascade constraints purge;
DROP TABLE arch_data_instance cascade constraints purge;
DROP TABLE data_instance cascade constraints purge;
DROP TABLE dependencymapping cascade constraints purge;
DROP TABLE dependency cascade constraints purge;
DROP TABLE pdependencymapping cascade constraints purge;
DROP TABLE pdependency cascade constraints purge;
DROP TABLE external_identity_mapping cascade constraints purge;
DROP TABLE user_membership cascade constraints purge;
DROP TABLE custom_usr_inf_val cascade constraints purge;
DROP TABLE custom_usr_inf_def cascade constraints purge;
DROP TABLE user_contactinfo cascade constraints purge;
DROP TABLE user_login cascade constraints purge;
DROP TABLE user_ cascade constraints purge;
DROP TABLE role cascade constraints purge;
DROP TABLE group_ cascade constraints purge;
DROP TABLE queriablelog_p cascade constraints purge;
DROP TABLE queriable_log cascade constraints purge;
DROP TABLE page cascade constraints purge;
DROP TABLE theme cascade constraints purge;
DROP TABLE blob_ cascade constraints purge;
DROP TABLE profilemember cascade constraints purge;
DROP TABLE profileentry cascade constraints purge;
DROP TABLE profile cascade constraints purge;
DROP TABLE job_log cascade constraints purge;
DROP TABLE job_param cascade constraints purge;
DROP TABLE job_desc cascade constraints purge;
DROP TABLE sequence cascade constraints purge;
DROP TABLE tenant cascade constraints purge;
DROP TABLE platform cascade constraints purge;
DROP TABLE platformCommand cascade constraints purge;
DROP TABLE form_mapping cascade constraints purge;
DROP TABLE page_mapping cascade constraints purge;
DROP TABLE process_content cascade constraints purge;
